Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var FuncMap = template.FuncMap{ "ToLower": strings.ToLower, "GoName": generatego.CamelCase, }
FuncMap contains a series of utility functions to be passed into templates and used within those templates.
Functions ¶
Types ¶
type Data ¶
type Data struct {
// import path for the directory containing the definition .proto files
ImportPath string
// import path for .pb.go files containing service structs
PBImportPath string
// PackageName is the name of the package containing the service definition
PackageName string
// GRPC/Protobuff service, with all parameters and return values accessible
Service *svcdef.Service
// A helper struct for generating http transport functionality.
HTTPHelper *httptransport.Helper
FuncMap template.FuncMap
Version string
VersionDate string
}
Data is passed to templates as the executing struct; its fields and methods are used to modify the template
Directories
¶
| Path | Synopsis |
|---|---|
|
Package generator generates a gokit service based on a service definition.
|
Package generator generates a gokit service based on a service definition. |
|
Package handlers renders the Go source files found in <svcname>/handlers/.
|
Package handlers renders the Go source files found in <svcname>/handlers/. |
|
Package httptransport provides functions and template helpers for templating the http-transport of a go-kit based service.
|
Package httptransport provides functions and template helpers for templating the http-transport of a go-kit based service. |
|
This file is here to hold the `go generate` command above.
|
This file is here to hold the `go generate` command above. |
Click to show internal directories.
Click to hide internal directories.